@@ -20,9 +20,6 @@ class InputType(Enum):
     S3 = "S3"
     S3_ROLE_BASED = "S3_ROLE_BASED"
     SFTP = "SFTP"
-    TCP = "TCP"
-    UDP = "UDP"
-    UDP_MULTICAST = "UDP_MULTICAST"
     ZIXI = "ZIXI"
     SRT = "SRT"
     GCS_SERVICE_ACCOUNT = "GCS_SERVICE_ACCOUNT"
